##############
 Installation
##############

The most recent release can be installed from `PyPI
<https://pypi.org/project/bohicalog>`_ with:

.. code:: shell

   $ pip install bohicalog

The most recent code and data can be installed directly from GitHub
with:

.. code:: shell

   $ pip install git+https://github.com/BOHICA-Labs/bohicalog.git

To install in development mode, use the following:

.. code:: shell

   $ git clone git+https://github.com/BOHICA-Labs/bohicalog.git
   $ cd bohicalog
   $ pip install -e .
